==> ocsp-server-3.0.0-sources.jar: org/xipki/ocsp/server/impl/jaxb/ObjectFactory.java <==

package org.xipki.ocsp.server.impl.jaxb;

import javax.xml.bind.annotation.XmlRegistry;


/**
 * This object contains factory methods for each 
 * Java content interface and Java element interface 
 * generated in the org.xipki.ocsp.server.impl.jaxb package. 
 * <p>An ObjectFactory allows you to programatically 
 * construct new instances of the Java representation 
 * for XML content. The Java representation of XML 
 * content can consist of schema derived interfaces 
 * and classes representing the binding of schema 
 * type definitions, element declarations and model 
 * groups.  Factory methods for each of these are 
 * provided in this class.
 * 
 */
@XmlRegistry
public class ObjectFactory {


    /**
     * Create a new ObjectFactory that can be used to create new instances of schema derived classes for package: org.xipki.ocsp.server.impl.jaxb
     * 
     */
    public ObjectFactory() {
    }

    /**
     * Create an instance of {@link StoreType }
     * 
     */
    public StoreType createStoreType() {
        return new StoreType();
    }

    /**
     * Create an instance of {@link CertCollectionType }
     * 
     */
    public CertCollectionType createCertCollectionType() {
        return new CertCollectionType();
    }

    /**
     * Create an instance of {@link RequestOptionType }
     * 
     */
    public RequestOptionType createRequestOptionType() {
        return new RequestOptionType();
    }

    /**
     * Create an instance of {@link SignerType }
     * 
     */
    public SignerType createSignerType() {
        return new SignerType();
    }

    /**
     * Create an instance of {@link ResponderType }
     * 
     */
    public ResponderType createResponderType() {
        return new ResponderType();
    }

    /**
     * Create an instance of {@link OCSPServer }
     * 
     */
    public OCSPServer createOCSPServer() {
        return new OCSPServer();
    }

    /**
     * Create an instance of {@link ResponseCacheType }
     * 
     */
    public ResponseCacheType createResponseCacheType() {
        return new ResponseCacheType();
    }

    /**
     * Create an instance of {@link RespondersType }
     * 
     */
    public RespondersType createRespondersType() {
        return new RespondersType();
    }

    /**
     * Create an instance of {@link SignersType }
     * 
     */
    public SignersType createSignersType() {
        return new SignersType();
    }

    /**
     * Create an instance of {@link StoresType }
     * 
     */
    public StoresType createStoresType() {
        return new StoresType();
    }

    /**
     * Create an instance of {@link DatasourcesType }
     * 
     */
    public DatasourcesType createDatasourcesType() {
        return new DatasourcesType();
    }

    /**
     * Create an instance of {@link RequestOptionsType }
     * 
     */
    public RequestOptionsType createRequestOptionsType() {
        return new RequestOptionsType();
    }

    /**
     * Create an instance of {@link ResponseOptionsType }
     * 
     */
    public ResponseOptionsType createResponseOptionsType() {
        return new ResponseOptionsType();
    }

    /**
     * Create an instance of {@link ResponseOptionType }
     * 
     */
    public ResponseOptionType createResponseOptionType() {
        return new ResponseOptionType();
    }

    /**
     * Create an instance of {@link NonceType }
     * 
     */
    public NonceType createNonceType() {
        return new NonceType();
    }

    /**
     * Create an instance of {@link CacheType }
     * 
     */
    public CacheType createCacheType() {
        return new CacheType();
    }

    /**
     * Create an instance of {@link DatasourceType }
     * 
     */
    public DatasourceType createDatasourceType() {
        return new DatasourceType();
    }

    /**
     * Create an instance of {@link VersionsType }
     * 
     */
    public VersionsType createVersionsType() {
        return new VersionsType();
    }

    /**
     * Create an instance of {@link FileOrValueType }
     * 
     */
    public FileOrValueType createFileOrValueType() {
        return new FileOrValueType();
    }

    /**
     * Create an instance of {@link FileOrPlainValueType }
     * 
     */
    public FileOrPlainValueType createFileOrPlainValueType() {
        return new FileOrPlainValueType();
    }

    /**
     * Create an instance of {@link IncludesType }
     * 
     */
    public IncludesType createIncludesType() {
        return new IncludesType();
    }

    /**
     * Create an instance of {@link ExcludesType }
     * 
     */
    public ExcludesType createExcludesType() {
        return new ExcludesType();
    }

    /**
     * Create an instance of {@link StoreType.Source }
     * 
     */
    public StoreType.Source createStoreTypeSource() {
        return new StoreType.Source();
    }

    /**
     * Create an instance of {@link CertCollectionType.Keystore }
     * 
     */
    public CertCollectionType.Keystore createCertCollectionTypeKeystore() {
        return new CertCollectionType.Keystore();
    }

    /**
     * Create an instance of {@link RequestOptionType.HashAlgorithms }
     * 
     */
    public RequestOptionType.HashAlgorithms createRequestOptionTypeHashAlgorithms() {
        return new RequestOptionType.HashAlgorithms();
    }

    /**
     * Create an instance of {@link RequestOptionType.CertpathValidation }
     * 
     */
    public RequestOptionType.CertpathValidation createRequestOptionTypeCertpathValidation() {
        return new RequestOptionType.CertpathValidation();
    }

    /**
     * Create an instance of {@link SignerType.Algorithms }
     * 
     */
    public SignerType.Algorithms createSignerTypeAlgorithms() {
        return new SignerType.Algorithms();
    }

    /**
     * Create an instance of {@link SignerType.CaCerts }
     * 
     */
    public SignerType.CaCerts createSignerTypeCaCerts() {
        return new SignerType.CaCerts();
    }

    /**
     * Create an instance of {@link ResponderType.ServletPaths }
     * 
     */
    public ResponderType.ServletPaths createResponderTypeServletPaths() {
        return new ResponderType.ServletPaths();
    }

    /**
     * Create an instance of {@link ResponderType.Stores }
     * 
     */
    public ResponderType.Stores createResponderTypeStores() {
        return new ResponderType.Stores();
    }

}

==> ocsp-server-4.0.0-sources.jar: org/xipki/ocsp/server/impl/jaxb/ObjectFactory.java <==

package org.xipki.ocsp.server.impl.jaxb;

import javax.xml.bind.annotation.XmlRegistry;


/**
 * This object contains factory methods for each 
 * Java content interface and Java element interface 
 * generated in the org.xipki.ocsp.server.impl.jaxb package. 
 * <p>An ObjectFactory allows you to programatically 
 * construct new instances of the Java representation 
 * for XML content. The Java representation of XML 
 * content can consist of schema derived interfaces 
 * and classes representing the binding of schema 
 * type definitions, element declarations and model 
 * groups.  Factory methods for each of these are 
 * provided in this class.
 * 
 */
@XmlRegistry
public class ObjectFactory {


    /**
     * Create a new ObjectFactory that can be used to create new instances of schema derived classes for package: org.xipki.ocsp.server.impl.jaxb
     * 
     */
    public ObjectFactory() {
    }

    /**
     * Create an instance of {@link StoreType }
     * 
     */
    public StoreType createStoreType() {
        return new StoreType();
    }

    /**
     * Create an instance of {@link CertCollectionType }
     * 
     */
    public CertCollectionType createCertCollectionType() {
        return new CertCollectionType();
    }

    /**
     * Create an instance of {@link RequestOptionType }
     * 
     */
    public RequestOptionType createRequestOptionType() {
        return new RequestOptionType();
    }

    /**
     * Create an instance of {@link SignerType }
     * 
     */
    public SignerType createSignerType() {
        return new SignerType();
    }

    /**
     * Create an instance of {@link ResponderType }
     * 
     */
    public ResponderType createResponderType() {
        return new ResponderType();
    }

    /**
     * Create an instance of {@link Ocspserver }
     * 
     */
    public Ocspserver createOcspserver() {
        return new Ocspserver();
    }

    /**
     * Create an instance of {@link ResponseCacheType }
     * 
     */
    public ResponseCacheType createResponseCacheType() {
        return new ResponseCacheType();
    }

    /**
     * Create an instance of {@link RespondersType }
     * 
     */
    public RespondersType createRespondersType() {
        return new RespondersType();
    }

    /**
     * Create an instance of {@link SignersType }
     * 
     */
    public SignersType createSignersType() {
        return new SignersType();
    }

    /**
     * Create an instance of {@link StoresType }
     * 
     */
    public StoresType createStoresType() {
        return new StoresType();
    }

    /**
     * Create an instance of {@link DatasourcesType }
     * 
     */
    public DatasourcesType createDatasourcesType() {
        return new DatasourcesType();
    }

    /**
     * Create an instance of {@link RequestOptionsType }
     * 
     */
    public RequestOptionsType createRequestOptionsType() {
        return new RequestOptionsType();
    }

    /**
     * Create an instance of {@link ResponseOptionsType }
     * 
     */
    public ResponseOptionsType createResponseOptionsType() {
        return new ResponseOptionsType();
    }

    /**
     * Create an instance of {@link ResponseOptionType }
     * 
     */
    public ResponseOptionType createResponseOptionType() {
        return new ResponseOptionType();
    }

    /**
     * Create an instance of {@link NonceType }
     * 
     */
    public NonceType createNonceType() {
        return new NonceType();
    }

    /**
     * Create an instance of {@link CacheType }
     * 
     */
    public CacheType createCacheType() {
        return new CacheType();
    }

    /**
     * Create an instance of {@link DatasourceType }
     * 
     */
    public DatasourceType createDatasourceType() {
        return new DatasourceType();
    }

    /**
     * Create an instance of {@link VersionsType }
     * 
     */
    public VersionsType createVersionsType() {
        return new VersionsType();
    }

    /**
     * Create an instance of {@link FileOrValueType }
     * 
     */
    public FileOrValueType createFileOrValueType() {
        return new FileOrValueType();
    }

    /**
     * Create an instance of {@link FileOrPlainValueType }
     * 
     */
    public FileOrPlainValueType createFileOrPlainValueType() {
        return new FileOrPlainValueType();
    }

    /**
     * Create an instance of {@link StoreType.Source }
     * 
     */
    public StoreType.Source createStoreTypeSource() {
        return new StoreType.Source();
    }

    /**
     * Create an instance of {@link CertCollectionType.Keystore }
     * 
     */
    public CertCollectionType.Keystore createCertCollectionTypeKeystore() {
        return new CertCollectionType.Keystore();
    }

    /**
     * Create an instance of {@link RequestOptionType.HashAlgorithms }
     * 
     */
    public RequestOptionType.HashAlgorithms createRequestOptionTypeHashAlgorithms() {
        return new RequestOptionType.HashAlgorithms();
    }

    /**
     * Create an instance of {@link RequestOptionType.CertpathValidation }
     * 
     */
    public RequestOptionType.CertpathValidation createRequestOptionTypeCertpathValidation() {
        return new RequestOptionType.CertpathValidation();
    }

    /**
     * Create an instance of {@link SignerType.Algorithms }
     * 
     */
    public SignerType.Algorithms createSignerTypeAlgorithms() {
        return new SignerType.Algorithms();
    }

    /**
     * Create an instance of {@link SignerType.CaCerts }
     * 
     */
    public SignerType.CaCerts createSignerTypeCaCerts() {
        return new SignerType.CaCerts();
    }

    /**
     * Create an instance of {@link ResponderType.ServletPaths }
     * 
     */
    public ResponderType.ServletPaths createResponderTypeServletPaths() {
        return new ResponderType.ServletPaths();
    }

    /**
     * Create an instance of {@link ResponderType.Stores }
     * 
     */
    public ResponderType.Stores createResponderTypeStores() {
        return new ResponderType.Stores();
    }

}
